Learn R Programming

coalescentMCMC (version 0.5)

treeOperators: Trees Operators for Running MCMC

Description

These functions provide tools for tree rearrangement to be used as operators in a MCMC run.

Usage

NeighborhoodRearrangement(phy, n, THETA, brtimes)
TipInterchange(phy, n)

Value

an object of class "phylo".

Arguments

phy

a tree of class "phylo".

n

the number of tips in phy.

THETA

The estimate of \(\Theta\) for phy at the node 'target'.

brtimes

the branching times of phy.

Author

Emmanuel Paradis

Details

NeighborhoodRearrangement performs a rearrangement as described by Kuhner et al. (1995).

TipInterchange interchanges two tips under the condition that they are not sisters.

EdgeLengthJittering alters the branch lengths by adding a random value from a uniform distribution defined by range(phy$edge.length) (the ultrametric nature of the tree is conserved).

References

Kuhner, M. K., Yamato, J. and Felsenstein, J. (1995) Estimating effective population size and mutation rate from sequence data using Metropolis-Hastings sampling. Genetics, 140, 1421--1430.

See Also

coalescentMCMC, dcoal

Examples

Run this code
tr <- rcoal(10)
ts <- NeighborhoodRearrangement(tr, 10, 1, branching.times(tr))
layout(matrix(1:2, 2))
plot(tr); plot(ts)
layout(1)

Run the code above in your browser using DataLab